/*
 * Copyright 2019 New Vector Ltd
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package im.vector.riotredesign.features.roomdirectory.roompreview

import android.os.Bundle
import android.view.View
import androidx.fragment.app.Fragment
import com.airbnb.mvrx.args
import im.vector.riotredesign.R
import im.vector.riotredesign.core.extensions.setTextOrHide
import im.vector.riotredesign.core.platform.VectorBaseFragment
import im.vector.riotredesign.features.home.AvatarRenderer
import im.vector.riotredesign.features.roomdirectory.RoomDirectoryModule
import kotlinx.android.synthetic.main.fragment_room_preview_no_preview.*
import org.koin.android.scope.ext.android.bindScope
import org.koin.android.scope.ext.android.getOrCreateScope

class RoomPreviewNoPreviewFragment : VectorBaseFragment() {

    companion object {
        fun newInstance(arg: RoomPreviewData): Fragment {
            return RoomPreviewNoPreviewFragment().apply { setArguments(arg) }
        }
    }

    private val roomPreviewData: RoomPreviewData by args()

    override fun onActivityCreated(savedInstanceState: Bundle?) {
        super.onActivityCreated(savedInstanceState)
        bindScope(getOrCreateScope(RoomDirectoryModule.ROOM_DIRECTORY_SCOPE))
        setupToolbar(roomPreviewNoPreviewToolbar)
    }

    override fun getLayoutResId() = R.layout.fragment_room_preview_no_preview

    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        AvatarRenderer.render(roomPreviewData.avatarUrl, roomPreviewData.roomId, roomPreviewData.roomName, roomPreviewNoPreviewAvatar)
        roomPreviewNoPreviewName.text = roomPreviewData.roomName
        roomPreviewNoPreviewTopic.setTextOrHide(roomPreviewData.topic)

        roomPreviewNoPreviewJoin.setOnClickListener {
            vectorBaseActivity.notImplemented("Join from preview")
        }
    }
}